doapfiend.model

Package doapfiend :: Module model |
[hide private]
[frames] | no frames]

# Module model

source code

Model of a DOAP profile using RDFAlchemy

Classes | [hide private]
| Project DOAP Project Class
| Release A release class
| SVNRepository Subversion repository classs
| CVSRepository CVS repository class

Variables | [hide private]
| DOAP = `rdflib.URIRef('http://usefulinc.com/ns/doap#')`
| FOAF = `rdflib.URIRef('http://xmlns.com/foaf/0.1/')`
| DC = `rdflib.URIRef('http://purl.org/dc/elements/1.1/')`